@@ -1,6 +1,8 @@
+import os
 from pathlib import Path
 from signal import Signals
 import subprocess
+import sys
 
 import toml
 
@@ -21,7 +23,7 @@ DOWNLOAD_SOURCES = {
 
 
 def aliases():
-    pyproject = toml.loads(Path("pyproject.toml").read_text())
+    pyproject = toml.loads(Path('pyproject.toml').read_text())
     return pyproject.get('tool', {}).get('bork', {}).get('aliases', {})
 
 
@@ -31,8 +33,8 @@ def build():
 
 
 def clean():
-    try_delete("./build")
-    try_delete("./dist")
+    try_delete('./build')
+    try_delete('./dist')
     for name in Path.cwd().glob('*.egg-info'):
         if name.is_dir():
             try_delete(name)
@@ -56,33 +58,47 @@ def download(package, release_tag, file_pattern, directory):
 
 def release(repository_name, dry_run):
     pyproject = toml.load('pyproject.toml')
+    bork_config = pyproject.get('tool', {}).get('bork', {})
+    release_config = bork_config.get('release', {})
+    github_token = os.environ.get('BORK_GITHUB_TOKEN', None)
+    version = builder.version_from_bdist_file()
 
-    try:
-        release_dict = pyproject['tool']['bork']['release']
-        strip_zipapp_version = release_dict.get('strip_zipapp_version', False)
-    except KeyError:
-        # Not an error.
-        strip_zipapp_version = False
+    project_name = bork_config.get('project_name', None)
 
-    try:
-        release_dict = pyproject['tool']['bork']['release']
-        release_to_github = release_dict.get('github', False)
-        release_to_pypi = release_dict.get('pypi', True)
-    except KeyError:
-        release_to_github = False
-        release_to_pypi = True
+    strip_zipapp_version = release_config.get('strip_zipapp_version', False)
+    globs = release_config.get('github_release_globs', ['./dist/*.pyz'])
+
+    release_to_github = release_config.get('github', False)
+    release_to_pypi = release_config.get('pypi', True)
 
     if not release_to_github and not release_to_pypi:
-        print("Configured to release to neither PyPi nor GitHub?")
+        print('Configured to release to neither PyPi nor GitHub?')
+
+    if release_to_github:
+        github_repository = release_config.get('github_repository', None)
+
+        if github_token is None:
+            logger().error('No GitHub token specified. Use the BORK_GITHUB_TOKEN '
+                      'environment variable to set it.')
+
+            if dry_run:
+                logger().error('When not using --dry-run, this error is fatal.')
+            else:
+                sys.exit(1)
+
+        config = github.GithubConfig(github_token, github_repository, project_name)
+        github_release = github.GithubRelease(
+            config, tag=f'v{version}', commitish=None, body=None,
+            globs=globs,
+            dry_run=dry_run, strip_zipapp_version=strip_zipapp_version)
+        github_release.prepare()
 
     if release_to_pypi:
         pypi.upload(repository_name, './dist/*.tar.gz', './dist/*.whl',
                     dry_run=dry_run)
 
     if release_to_github:
-        github.upload('./dist/*.pyz',
-                      dry_run=dry_run,
-                      strip_zipapp_version=strip_zipapp_version)
+        github_release.publish()
 
 
 def run(alias):
@@ -90,8 +106,8 @@ def run(alias):
 
     try:
         command = pyproject['tool']['bork']['aliases'][alias]
-    except KeyError:
-        raise RuntimeError("No such alias: '{}'".format(alias))
+    except KeyError as error:
+        raise RuntimeError("No such alias: '{}'".format(alias)) from error
 
     logger().info("Running '%s'", command)
 
